<?php

namespace Ali\Ali\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Ali\Ali\Http\Requests\AliRequest;
use Ali\Ali\Interfaces\AliRepositoryInterface;
use Ali\Ali\Models\Ali;

/**
 * Admin web controller class.
 */
class AliAdminController extends BaseController
{
    // use AliWorkflow;
    /**
     * Initialize ali controller.
     *
     * @param type AliRepositoryInterface $ali
     *
     * @return type
     */
    public function __construct(AliRepositoryInterface $ali)
    {
        $this->repository = $ali;
        parent::__construct();
    }

    /**
     * Display a list of ali.
     *
     * @return Response
     */
    public function index(AliRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('ali::ali.names').' :: ');
        return $this->theme->of('ali::admin.ali.index')->render();
    }

    /**
     * Display a list of ali.
     *
     * @return Response
     */
    public function getJson(AliRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $alis  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Ali\\Ali\\Repositories\\Presenter\\AliListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $alis['recordsTotal']    = $alis['meta']['pagination']['total'];
        $alis['recordsFiltered'] = $alis['meta']['pagination']['total'];
        $alis['request']         = $request->all();
        return response()->json($alis, 200);

    }

    /**
     * Display ali.
     *
     * @param Request $request
     * @param Model   $ali
     *
     * @return Response
     */
    public function show(AliRequest $request, Ali $ali)
    {
        if (!$ali->exists) {
            return response()->view('ali::admin.ali.new', compact('ali'));
        }

        Form::populate($ali);
        return response()->view('ali::admin.ali.show', compact('ali'));
    }

    /**
     * Show the form for creating a new ali.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AliRequest $request)
    {

        $ali = $this->repository->newInstance([]);

        Form::populate($ali);

        return response()->view('ali::admin.ali.create', compact('ali'));

    }

    /**
     * Create new ali.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AliRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $ali          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('ali::ali.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/ali/ali/'.$ali->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show ali for editing.
     *
     * @param Request $request
     * @param Model   $ali
     *
     * @return Response
     */
    public function edit(AliRequest $request, Ali $ali)
    {
        Form::populate($ali);
        return  response()->view('ali::admin.ali.edit', compact('ali'));
    }

    /**
     * Update the ali.
     *
     * @param Request $request
     * @param Model   $ali
     *
     * @return Response
     */
    public function update(AliRequest $request, Ali $ali)
    {
        try {

            $attributes = $request->all();

            $ali->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('ali::ali.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/ali/ali/'.$ali->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/ali/ali/'.$ali->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the ali.
     *
     * @param Model   $ali
     *
     * @return Response
     */
    public function destroy(AliRequest $request, Ali $ali)
    {

        try {

            $t = $ali->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('ali::ali.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/ali/ali/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/ali/ali/'.$ali->getRouteKey()),
            ], 400);
        }
    }

}
