<?php

namespace Ali\Ali\Http\Controllers;
use Litepie\Ali\Http\Requests\AliRequest;
use Litepie\Ali\Models\Ali;

trait AliWorkflow {
	
    /**
     * Workflow controller function for ali.
     *
     * @param Model   $ali
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AliRequest $request, Ali $ali, $step)
    {

        try {

            $ali->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('ali::ali.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/ali/ali/' . $ali->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/ali/ali/' . $ali->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for ali.
     *
     * @param Model   $ali
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Ali $ali, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $ali->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('ali::ali.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('ali::admin.ali.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('ali::admin.ali.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('ali::admin.ali.message', $data)->render();

        }

    }
}