<?php

namespace Ali\Ali\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Ali\Ali\Interfaces\AliRepositoryInterface;
use Ali\Ali\Repositories\Presenter\AliItemTransformer;

/**
 * Pubic API controller class.
 */
class AliPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Ali\Ali\Interfaces\AliRepositoryInterface $ali
     *
     * @return type
     */
    public function __construct(AliRepositoryInterface $ali)
    {
        $this->repository = $ali;
        parent::__construct();
    }

    /**
     * Show ali's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $alis = $this->repository
            ->setPresenter('\\Ali\\Ali\\Repositories\\Presenter\\AliListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $alis['code'] = 2000;
        return response()->json($alis)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show ali.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $ali = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($ali)) {
            $ali         = $this->itemPresenter($module, new AliItemTransformer);
            $ali['code'] = 2001;
            return response()->json($ali)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
