<?php

namespace Ali\Ali\Policies;

use App\User;
use Ali\Ali\Models\Ali;

class AliPolicy
{

    /**
     * Determine if the given user can view the ali.
     *
     * @param User $user
     * @param Ali $ali
     *
     * @return bool
     */
    public function view(User $user, Ali $ali)
    {
        if ($user->canDo('ali.ali.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $ali->user_id;
    }

    /**
     * Determine if the given user can create a ali.
     *
     * @param User $user
     * @param Ali $ali
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('ali.ali.create');
    }

    /**
     * Determine if the given user can update the given ali.
     *
     * @param User $user
     * @param Ali $ali
     *
     * @return bool
     */
    public function update(User $user, Ali $ali)
    {
        if ($user->canDo('ali.ali.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $ali->user_id;
    }

    /**
     * Determine if the given user can delete the given ali.
     *
     * @param User $user
     * @param Ali $ali
     *
     * @return bool
     */
    public function destroy(User $user, Ali $ali)
    {
        if ($user->canDo('ali.ali.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $ali->user_id;
    }

    /**
     * Determine if the given user can verify the given ali.
     *
     * @param User $user
     * @param Ali $ali
     *
     * @return bool
     */
    public function verify(User $user, Ali $ali)
    {
        if ($user->canDo('ali.ali.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('ali.ali.verify') 
        && $user->is('manager')
        && $ali->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ali.
     *
     * @param User $user
     * @param Ali $ali
     *
     * @return bool
     */
    public function approve(User $user, Ali $ali)
    {
        if ($user->canDo('ali.ali.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
