<?php

namespace Ali\Ali\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Ali\Ali\Models\Ali;

class AliAction
{
    /**
     * Perform the complete action.
     *
     * @param Ali $ali
     *
     * @return Ali
     */
    public function complete(Ali $ali)
    {
        try {
            $ali->status = 'complete';
            return $ali->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Ali $ali
     *
     * @return Ali
     */public function verify(Ali $ali)
    {
        try {
            $ali->status = 'verify';
            return $ali->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Ali $ali
     *
     * @return Ali
     */public function approve(Ali $ali)
    {
        try {
            $ali->status = 'approve';
            return $ali->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Ali $ali
     *
     * @return Ali
     */public function publish(Ali $ali)
    {
        try {
            $ali->status = 'publish';
            return $ali->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Ali $ali
     *
     * @return Ali
     */
    public function archive(Ali $ali)
    {
        try {
            $ali->status = 'archive';
            return $ali->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Ali $ali
     *
     * @return Ali
     */
    public function unpublish(Ali $ali)
    {
        try {
            $ali->status = 'unpublish';
            return $ali->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
