<?php

namespace Ali\Ali\Workflow;

use Ali\Ali\Models\Ali;
use Validator;

class AliValidator
{

    /**
     * Determine if the given ali is valid for complete status.
     *
     * @param Ali $ali
     *
     * @return bool / Validator
     */
    public function complete(Ali $ali)
    {
        return Validator::make($ali->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given ali is valid for verify status.
     *
     * @param Ali $ali
     *
     * @return bool / Validator
     */
    public function verify(Ali $ali)
    {
        return Validator::make($ali->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given ali is valid for approve status.
     *
     * @param Ali $ali
     *
     * @return bool / Validator
     */
    public function approve(Ali $ali)
    {
        return Validator::make($ali->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given ali is valid for publish status.
     *
     * @param Ali $ali
     *
     * @return bool / Validator
     */
    public function publish(Ali $ali)
    {
        return Validator::make($ali->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given ali is valid for archive status.
     *
     * @param Ali $ali
     *
     * @return bool / Validator
     */
    public function archive(Ali $ali)
    {
        return Validator::make($ali->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given ali is valid for unpublish status.
     *
     * @param Ali $ali
     *
     * @return bool / Validator
     */
    public function unpublish(Ali $ali)
    {
        return Validator::make($ali->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
